﻿using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Text;

namespace MapMvc.Controllers
{
    [HandleError]
    public class MapController : Controller, IMapInitializer
    {
        public void SetupInitializer()
        {
            MapInitializerHelper.GetInstance().SetInitializer(this);
        }

        public ActionResult RefinerMap()
        {
            return View();
        }

        public void InitializeMap(ThinkGeo.MapSuite.WebEdition.Map map)
        {
            map.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.White);
            map.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            map.MapUnit = GeographyUnit.DecimalDegree;

            WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
            map.CustomOverlays.Add(worldMapKitOverlay);

            string tempPath = System.AppDomain.CurrentDomain.BaseDirectory.TrimEnd('\\');
            string fullPath = tempPath + "\\App_Data\\STATES.SHP";
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(fullPath);
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add(worldLayer);
            staticOverlay.IsBaseOverlay = false;
            map.CustomOverlays.Add(staticOverlay);

            AddPopup(map);
        }

        private void AddPopup(Map map)
        {
            PointShape position = new PointShape(-95.28109, 38.95363);
            StringBuilder contentHtml = new StringBuilder();

            contentHtml.Append("<div style='padding:10px; font-size:10px; font-family:verdana;'><img align='left' width='150' height='130'")
                .Append("src='http://upload.wikimedia.org/wikipedia/commons/thumb/a/a9/Douglas_county_kansas_courthouse.jpg/250px-Douglas_county_kansas_courthouse.jpg'/>&nbsp;&nbsp;Lawrence is a city in Northeastern Kansas")
                .Append("in the United States. Lawrence serves as the county seat of Douglas County, Kansas. Located 41 miles west ")
                .Append("of Kansas City, Lawrence is situated along the banks of the Kansas (Kaw) and Wakarusa Rivers. ")
                .Append("&nbsp;&nbsp;<a href='http://en.wikipedia.org/wiki/Lawrence%2C_Kansas' ")
                .Append("target='_blank'><br/>more about Lawrence city...</a></div>");

            CloudPopup samplePopup = new CloudPopup("samplePopup", position, contentHtml.ToString(), 300, 200);
            samplePopup.AutoPan = true;
            samplePopup.HasCloseButton = true;
            map.Popups.Add(samplePopup);
        }
    }
}
